* [Home](https://help.sap.com/docs/)
  * [SAP LeanIX](https://help.sap.com/docs/leanix)
  * …
  * [Obsolescence Risk Management](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management)
  * Step 4: Plan and Manage Risk Mitigation Initiatives
